@@ -1,15 +1,16 @@
 from __future__ import annotations
 
 from functools import partial
-from typing import Type, Generic
+from typing import Type, Generic, Callable
 
 import orjson
 from sanic import Sanic
 
+from web_foundation.config import AppConf
 from web_foundation.extentions.error_handler import ExtendedErrorHandler
+from web_foundation.extentions.realtime.rt_broadcaster import RtBroadcaster
 from web_foundation.extentions.realtime.rt_connection import RtEventCallback
 from web_foundation.extentions.router import ExtRouter
-from web_foundation.extentions.realtime.rt_broadcaster import RtBroadcaster
 from web_foundation.extentions.sanic_ext_worker import ExtWorker
 from web_foundation.kernel.channel import IChannel, IMessage, GenericIMessage
 from web_foundation.kernel.container import GenericDependencyContainer
@@ -21,14 +22,17 @@ class App(Generic[GenericDependencyContainer]):
     name: str
     container: GenericDependencyContainer
     sanic: Sanic
+    config: AppConf
     dispatcher: IDispatcher
+    # listeners: Dict[str, List[AppListener]]
     _rt_listeners = list[tuple[list[Type[IMessage] | str], RtEventCallback, bool]]
 
-    def __init__(self, name: str, dependency_container: GenericDependencyContainer,
+    def __init__(self, dependency_container: GenericDependencyContainer,
                  dispatcher: IDispatcher = None, with_addons=False):
-        self.name = name
+        self.name = dependency_container.app_config().app_name
         self.container = dependency_container
-        self.sanic = Sanic(name, loads=orjson.loads, dumps=orjson.dumps, error_handler=ExtendedErrorHandler())
+        self.sanic = Sanic(self.name, loads=orjson.loads, dumps=orjson.dumps,
+                           error_handler=ExtendedErrorHandler())
         self.dispatcher = dispatcher if dispatcher else IDispatcher()
         self._rt_listeners = []
         self.add_isolate("Dispatcher", IDispatcherIsolate, dispatcher=self.dispatcher, add_channel=False, daemon=False)
@@ -92,6 +96,7 @@ class App(Generic[GenericDependencyContainer]):
 
     def _configure_sanic_worker(self):
         async def set_worker_ctx(s_app: Sanic):
+
             # set channel to ctx
             worker_num = int(s_app.m.name.split('-')[-2])
             s_app.ctx.channel = getattr(s_app.shared_ctx, f"Channel_{worker_num}")
@@ -107,6 +112,7 @@ class App(Generic[GenericDependencyContainer]):
                     event_type=event,
                     callback=partial(s_app.ctx.rt_broadcaster.broadcast, resolve_callback=resolver),
                     use_nested_classes=use_nested_classes)
+            await self.container.init_resources(s_app.ctx.channel)
 
         self.sanic.before_server_start(set_worker_ctx)
 
@@ -116,8 +122,27 @@ class App(Generic[GenericDependencyContainer]):
 
         self.sanic.after_server_start(listen_channel)
 
+        async def on_stop(s_app: Sanic):
+            await self.container.shutdown_resources()
+
+        self.sanic.before_server_stop(on_stop)
+
+    # def _add_listener(self, scope: str, listener: AppListener):
+    #     if not self.listeners.get(scope):
+    #         self.listeners[scope] = []
+    #     self.listeners[scope].append(listener)
+    #
+    # def before_resources_init(self, listener: AppListener):
+    #     self._add_listener("before_resource", listener)
+    #
+    # def before_app_start(self):
+    #     pass
+
     def run(self, *args, **kwargs):
         self._set_sanic_confs()
         self._configure_sanic_main()
         self._configure_sanic_worker()
         self.sanic.run(*args, **kwargs)
+
+
+AppListener = Callable[[App], None]
