@@ -1,13 +1,13 @@
 from __future__ import annotations
+
 import asyncio
-from dataclasses import dataclass
-from enum import Enum
-from typing import Coroutine, Callable, Dict, Type, List, Set, Any
+from multiprocessing import Queue
+from typing import Coroutine, Callable, Dict, Type, List, Any
 from typing import TypeVar
 
-import loguru
-from aioprocessing import AioEvent, AioLock, AioQueue  # type: ignore
+from aioprocessing import AioQueue
 from loguru import logger
+
 from web_foundation import settings
 
 
@@ -30,31 +30,9 @@ class IMessage:
 
 GenericIMessage = TypeVar("GenericIMessage", bound=IMessage, contravariant=True)
 
-
-@dataclass
-class IsolatePipes:
-    queue: AioQueue
-    event: AioEvent
-    lock: AioLock
-
-    async def write(self, msg: GenericIMessage):
-        await self.queue.coro_put(msg)
-
-    async def read(self) -> GenericIMessage:
-        return await self.queue.coro_get()
-
-    def empty(self):
-        return self.queue.empty()
-
-
 EventListener = Callable[[GenericIMessage], Coroutine]
 
 
-class MessageWaitState(Enum):
-    PENDING = "PENDING"
-    DONE = "DONE"
-
-
 class IMessageWaiter:
     event = asyncio.Event()
     result: Any = None
@@ -66,13 +44,11 @@ class IMessageWaiter:
 
 class IChannel:
     read_timeout = 0.01
-    pipes: IsolatePipes
     worker_name: str
-    consume_pipe: IsolatePipes
-    produce_pipe: IsolatePipes
+    consume_pipe: AioQueue
+    produce_pipe: Queue
 
     _listeners: Dict[str, List[EventListener]]
-    _once_listeners: Dict[str, EventListener]
     _response_waiters: Dict[int, IMessageWaiter]
 
     _before_event_middlewares: Dict[str, EventListener]
@@ -84,10 +60,9 @@ class IChannel:
         self.worker_name = isolate_name
         # self.debug = debug
         self._listeners = {}
-        self._once_listeners = {}
         self._response_waiters = {}
-        self.produce_pipe = IsolatePipes(AioQueue(), AioEvent(), AioLock())
-        self.consume_pipe = IsolatePipes(AioQueue(), AioEvent(), AioLock())
+        self.consume_pipe = Queue()
+        self.produce_pipe = Queue()
         self._after_event_middlewares = {}
         self._before_event_middlewares = {}
 
@@ -105,14 +80,16 @@ class IChannel:
             listeners = self._listeners.get(msg.message_type)
             for listener in listeners:
                 asyncio.create_task(listener(msg))
-        await self.produce_pipe.write(msg)
+        self.produce_pipe.put(msg)
 
     async def sent_to_consume(self, msg: IMessage):
-        await self.consume_pipe.write(msg)
+        self.consume_pipe.put(msg)
 
     async def listen_produce(self, callback: Callable[[GenericIMessage], Coroutine]):
         while True:
-            r: GenericIMessage = await self.produce_pipe.read()
+            while self.produce_pipe.empty():
+                await asyncio.sleep(0.1)
+            r: GenericIMessage = self.produce_pipe.get()
             if settings.DEBUG:
                 logger.info(
                     f"Channel {self.worker_name} send message: {r.message_type}")
@@ -120,13 +97,12 @@ class IChannel:
 
     async def listen_consume(self):
         while True:
-            r: IMessage = await self.consume_pipe.read()
+            while self.consume_pipe.empty():
+                await asyncio.sleep(0.1)
+            r: IMessage = self.consume_pipe.get()
             if settings.DEBUG:
                 logger.info(
                     f"Channel {self.worker_name} receive message: {r.message_type}")
-            once_callback = self._once_listeners.get(r.message_type)
-            if once_callback:
-                asyncio.create_task(self._exec_once(r, once_callback))
             after_middleware = self._after_event_middlewares.get(r.message_type)
             if after_middleware:
                 asyncio.create_task(after_middleware(r))
@@ -139,10 +115,6 @@ class IChannel:
             for callback in callbacks:
                 asyncio.create_task(callback(r))
 
-    async def _exec_once(self, msg: GenericIMessage, callback: EventListener):
-        await callback(msg)
-        self._once_listeners.pop(msg.message_type)
-
     def add_event_middleware(self, event_type: str, callback: EventListener, assign_to: str = "after"):
         """
         :param callback: callback to call
@@ -200,9 +172,6 @@ class IChannel:
         else:
             self._add_event_listener(event_type, callback, use_nested_classes)
 
-    def add_once_listener(self, event_type: str, callback: EventListener):
-        self._once_listeners.update({event_type: callback})
-
     def remove_event_listeners(self, event_type: Type[IMessage] | str):
         if isinstance(event_type, str):
             self._listeners.pop(event_type)
