@@ -5,12 +5,13 @@ from typing import TypeVar
 from pydantic import BaseSettings
 
 from web_foundation.config import GenericConfig
+from web_foundation.kernel.channel import IChannel
 from web_foundation.kernel.resource import Resource
 from web_foundation.resources.files.interface import FilesResource
 from web_foundation.kernel.dependency import Dependency
 from web_foundation.resources.stores.interface import DataStore
 from web_foundation.services.service import Service
-from web_foundation.utils.helpers import in_obj_subclasses
+from web_foundation.utils.helpers import in_obj_subclasses, in_obj_classes
 
 
 class DependencyContainer:
@@ -18,9 +19,15 @@ class DependencyContainer:
     data_store: Dependency[DataStore] = Dependency(instance_of=DataStore)
     file_repository: Dependency[FilesResource] = Dependency(instance_of=FilesResource)
 
-    async def init_resources(self):
+    def __init__(self, **kwargs):
+        for dep, name in in_obj_classes(self, Dependency):
+            dep_init = kwargs.get(name)
+            if dep_init:
+                dep.from_initialized(dep_init)
+
+    async def init_resources(self, channel: IChannel | None = None):
         for resource, name in in_obj_subclasses(self, Resource):
-            await resource.init(self.app_config())
+            await resource.init(self.app_config(), channel)
 
     async def shutdown_resources(self):
         for resource, name in in_obj_subclasses(self, Resource):
